_`umbra.components.addons.traceUi.models`
=========================================

.. automodule:: umbra.components.addons.traceUi.models

Module Attributes
-----------------

.. attribute:: umbra.components.addons.traceUi.models.LOGGER

Classes
-------

.. autoclass:: ModulesModel
	:show-inheritance:
	:members:

